/// <reference types="webpack-serve" />
import webpack, { Configuration, Rule, PerformanceOptions, Output, Entry } from 'webpack';
import MiniCssExtractPlugin from 'mini-css-extract-plugin';
import HtmlWebpackPlugin from 'html-webpack-plugin';
import { EnvOptions } from '../../options';
/**
 * We make some properties of `webpack.Configuration` mandatory. It is easier for future usage, so we don't
 * need to check, if they are available or not.
 */
export declare type StrictOutput = Output & {
    filename: string;
    path: string;
};
export interface WebpackConfig extends Configuration {
    entry: Entry;
    output: StrictOutput;
}
export declare const nodeSourceMapEntry = "source-map-support/register";
export declare const performance: PerformanceOptions;
export declare const babelNode: {
    presets: any[];
    plugins: any[];
    compact: boolean;
};
export declare const babelBrowser: {
    presets: any[];
    plugins: any[];
    compact: boolean;
};
export declare type Command = 'build' | 'build -p' | 'unit' | 'e2e';
export declare const getHappyPackPluginJs: (target: "spa" | "node" | "browser", command: Command) => any;
export declare const getHappyPackPluginTs: (target: "spa" | "node" | "browser", command: Command) => any;
export declare const imageRule: Rule;
export declare const eotRule: Rule;
export declare const woffRule: Rule;
export declare const ttfRule: Rule;
export declare const miniCssExtractPlugin: MiniCssExtractPlugin;
export declare const miniCssExtractPluginHashed: MiniCssExtractPlugin;
export declare const defineProductionPlugin: webpack.DefinePlugin;
export declare const indexHtmlPlugin: HtmlWebpackPlugin;
export declare const resolveLoader: {
    modules: string[];
    alias: {
        ['copy-loader']: string;
    };
};
export declare const extensions: string[];
export declare const resolve: {
    extensions: string[];
    mainFields: string[];
};
export declare const defaultLoaderOptions: {
    resolve: {
        extensions: string[];
    };
};
export declare const loaderOptionsPlugin: webpack.LoaderOptionsPlugin;
export declare const productionOptionsPlugin: webpack.LoaderOptionsPlugin;
export declare const forkTsCheckerPlugin: any;
export declare const devtool = "inline-source-map";
export declare const devtoolProduction = "source-map";
export declare const externalsSpa: any[];
export declare const externalsNode: webpack.ExternalsFunctionElement[];
export declare const externalsBrowser: any[];
export declare const enzymeExternals: string[];
export declare const node: {
    __dirname: boolean;
    __filename: boolean;
};
export declare const stats: Configuration['stats'];
export declare const baseConfig: Configuration;
export declare const releaseConfig: Configuration;
export declare const nodeConfig: Configuration;
export declare type Target = 'spa' | 'node' | 'browser';
export declare const getEntryAndOutput: (target: "spa" | "node" | "browser", command: Command) => {
    entry: webpack.Entry;
    output: StrictOutput;
};
export declare const getModuleAndPlugins: (target: "spa" | "node" | "browser", command: Command, options: EnvOptions) => {
    module: {
        rules: webpack.RuleSetRule[];
    };
    plugins: webpack.Plugin[];
};
